@@ -229,6 +229,7 @@ class NormalUI(IJobRunnerUI):
     def wait_for_interaction_prompt(self, job):
         return self.pick_action_cmd([
             Action('', _("press ENTER to continue"), 'run'),
+            Action('c', _('add a comment'), 'comment'),
             Action('s', _("skip this job"), 'skip'),
             Action('q', _("save the session and quit"), 'quit')
         ])
@@ -719,7 +720,8 @@ class RunInvocation(CheckBoxInvocationMixIn):
         self.run_single_job_with_ui(job, self.get_ui_for_job(job))
 
     def get_ui_for_job(self, job):
-        if job.plugin in ('local', 'resource', 'attachment'):
+        if self.ns.dont_suppress_output is False and job.plugin in (
+                'local', 'resource', 'attachment'):
             return NormalUI(self.C.c, show_cmd_output=False)
         else:
             return NormalUI(self.C.c, show_cmd_output=True)
@@ -747,6 +749,7 @@ class RunInvocation(CheckBoxInvocationMixIn):
         ui.finished(job, job_state, job_result)
 
     def _run_single_job_with_ui_loop(self, job, ui):
+        comments = ""
         while True:
             if job.plugin in ('user-interact', 'user-interact-verify',
                               'user-verify', 'manual'):
@@ -756,11 +759,19 @@ class RunInvocation(CheckBoxInvocationMixIn):
                 cmd = ui.wait_for_interaction_prompt(job)
                 if cmd == 'run' or cmd is None:
                     job_result = self.runner.run_job(job, self.config, ui)
+                elif cmd == 'comment':
+                    new_comment = input(self.C.BLUE(
+                        _('Please enter your comments:') + '\n'))
+                    if new_comment:
+                        comments += new_comment + '\n'
+                    continue
                 elif cmd == 'skip':
                     job_result = MemoryJobResult({
                         'outcome': IJobResult.OUTCOME_SKIP,
                         'comments': _("Explicitly skipped before execution")
                     })
+                    if comments != "":
+                        job_result.comments = comments
                     break
                 elif cmd == 'quit':
                     raise SystemExit()
@@ -769,6 +780,8 @@ class RunInvocation(CheckBoxInvocationMixIn):
             if (self.is_interactive and
                     job_result.outcome == IJobResult.OUTCOME_UNDECIDED):
                 try:
+                    if comments != "":
+                        job_result.comments = comments
                     job_result = self._interaction_callback(
                         self.runner, job, job_result, self.config)
                 except ReRunJob:
@@ -879,7 +892,7 @@ class RunInvocation(CheckBoxInvocationMixIn):
     def _update_desired_job_list(self, desired_job_list):
         problem_list = self.state.update_desired_job_list(desired_job_list)
         if problem_list:
-            print(self.C.header_("Warning", 'YELLOW'))
+            print(self.C.header(_("Warning"), 'YELLOW'))
             print(_("There were some problems with the selected jobs"))
             for problem in problem_list:
                 print(" * {}".format(problem))
@@ -974,6 +987,9 @@ class RunCommand(PlainBoxCommand, CheckBoxCommandMixIn):
         group.add_argument(
             '-n', '--dry-run', action='store_true',
             help=_("don't really run most jobs"))
+        group.add_argument(
+            '--dont-suppress-output', action="store_true", default=False,
+            help=_("don't suppress the output of certain job plugin types"))
         group = parser.add_argument_group(_("output options"))
         assert 'text' in get_all_exporters()
         group.add_argument(
