@@ -193,6 +193,7 @@ class Explorer:
                     ('description', provider.description),
                     ('tr_description', provider.tr_description()),
                     ('jobs_dir', provider.jobs_dir),
+                    ('units_dir', provider.units_dir),
                     ('whitelists_dir', provider.whitelists_dir),
                     ('data_dir', provider.data_dir),
                     ('locale_dir', provider.locale_dir),
@@ -299,6 +300,7 @@ class Service:
         # TODO: if something fails destroy storage
         session = SessionState(job_list)
         session.open()
+        self._session_list.append(session)
         return session
 
     def get_all_exporters(self):
