@@ -42,6 +42,7 @@ from plainbox.i18n import gettext_noop as N_
 from plainbox.impl.buildsystems import all_buildsystems
 from plainbox.impl.commands import ToolBase, CommandBase
 from plainbox.impl.job import JobDefinition
+from plainbox.impl.unit import UnitWithId
 from plainbox.impl.logging import setup_logging
 from plainbox.impl.providers.v1 import get_user_PROVIDERPATH_entry
 from plainbox.impl.secure.config import Unset
@@ -51,7 +52,7 @@ from plainbox.impl.secure.providers.v1 import Provider1
 from plainbox.impl.secure.providers.v1 import Provider1Definition
 from plainbox.impl.secure.rfc822 import RFC822SyntaxError
 from plainbox.impl.validation import Problem
-from plainbox.impl.validation import ValidationError as JobValidationError
+from plainbox.impl.validation import ValidationError as UnitValidationError
 
 __all__ = ['setup', 'manage_py_extension']
 
@@ -500,7 +501,7 @@ class DevelopCommand(ManageCommand):
         parser.add_argument(
             "-d", "--directory", action="store",
             default=get_user_PROVIDERPATH_entry(),
-            help=_("directory to use (defaults to user's home provider path"))
+            help=_("directory to use (defaults to user's home provider path)"))
 
     def invoked(self, ns):
         pathname = os.path.join(
@@ -827,7 +828,9 @@ class InfoCommand(ManageCommand):
             # 0: unit representation
             # 1: pathname of the file the job is defined in
             print("\t" + _("{0} {1}, from {2}").format(
-                unit.get_unit_type(), unit,
+                unit.get_unit_type(),
+                unit.id if isinstance(unit, (UnitWithId, JobDefinition)) \
+                    else unit,
                 unit.origin.relative_to(self.definition.location)))
         if problem_list:
             print("\t" + _("Some units could not be parsed correctly"))
@@ -939,21 +942,21 @@ class ValidateCommand(ManageCommand):
                     print("{}".format(exc))
             print(_("NOTE: subsequent units from problematic"
                     " files are ignored"))
-        return unit_list
+        return unit_list, problem_list
 
     def validate_units(self, unit_list, ns):
         problem_list = []
         for unit in unit_list:
             try:
                 unit.validate(strict=ns.strict, deprecated=ns.deprecated)
-            except JobValidationError as exc:
+            except UnitValidationError as exc:
                 problem_list.append((unit, exc))
         return problem_list
 
     def invoked(self, ns):
         provider = self.get_provider()
-        unit_list = self.get_unit_list(provider)
-        problem_list = self.validate_units(unit_list, ns)
+        unit_list, load_problem_list = self.get_unit_list(provider)
+        validation_problem_list = self.validate_units(unit_list, ns)
         explain = {
             Problem.missing: _("missing definition of required field"),
             Problem.wrong: _("incorrect value supplied"),
@@ -962,16 +965,20 @@ class ValidateCommand(ManageCommand):
             Problem.constant: _("template field is constant"),
             Problem.variable: _("template field is variable"),
         }
-        for job, error in problem_list:
-            if isinstance(error, JobValidationError):
+        for unit, error in validation_problem_list:
+            if isinstance(error, UnitValidationError):
                 # TRANSLATORS: fields are as follows:
                 # 0: filename with job definition
-                # 1: job id
-                # 2: field name
-                # 3: explanation of the problem
-                print(_("{0}: job {1!a}, field {2!a}: {3}").format(
-                    job.origin.relative_to(self.definition.location),
-                    job.id, error.field.name, explain[error.problem]))
+                # 1: unit type name
+                # 2: unit identifier
+                # 3: field name
+                # 4: explanation of the problem
+                print(_("{0}: {1} {2!a}, field {3!a}: {4}").format(
+                    unit.origin.relative_to(self.definition.location),
+                    unit.get_unit_type(),
+                    unit.id if isinstance(unit, (UnitWithId, JobDefinition)) \
+                        else unit,
+                    str(error.field), explain[error.problem]))
                 # If this is a "wrong value" problem then perhaps we can
                 # suggest the set of acceptable values? Those may be stored as
                 # $field.symbols, though as of this writing that is only true
@@ -984,10 +991,10 @@ class ValidateCommand(ManageCommand):
                         ', '.join(str(symbol) for symbol in symbol_list)))
             else:
                 print(str(error))
-        if problem_list:
+        if validation_problem_list or load_problem_list:
             return 1
         else:
-            print(_("All jobs seem to be valid"))
+            print(_("The provider seems to be valid"))
 
     def get_provider(self):
         """
