@@ -58,6 +58,8 @@ class ProviderManagerToolTests(TestCase):
                 """
                 usage: manage.py [--help] [--version] [options]
 
+                Per-provider management script
+
                 positional arguments:
                   {info,validate,develop,install,sdist,i18n,build,clean}
                     info                display basic information about this provider
@@ -125,7 +127,8 @@ class ProviderManagerToolTests(TestCase):
             self.tmpdir + os.path.join("/foo", "lib", "plainbox-providers-1",
                                        "2014.com.example:test", "jobs",
                                        "jobs.txt"),
-            "id: dummy\nplugin: shell\ncommand: true\n")
+            ("id: dummy\nplugin: shell\ncommand: true\n"
+             "estimated_duration: 10\n"))
 
     def test_install__flat_partial(self):
         """
@@ -160,7 +163,7 @@ class ProviderManagerToolTests(TestCase):
         self.assertFileContent(
             self.tmpdir + os.path.join(
                 prefix, "share", "2014.com.example:test", "jobs", "jobs.txt"),
-            "id: dummy\nplugin: shell\ncommand: true\n")
+            "id: dummy\nplugin: shell\ncommand: true\nestimated_duration: 10\n")
         self.assertFileContent(
             self.tmpdir + os.path.join(
                 prefix, "share",  "2014.com.example:test", "whitelists",
@@ -206,7 +209,7 @@ class ProviderManagerToolTests(TestCase):
             self.tmpdir, "dist", "2014.com.example.test-1.0.tar.gz")
         self.assertTarballContent(
             tarball, "2014.com.example.test-1.0/jobs/jobs.txt",
-            "id: dummy\nplugin: shell\ncommand: true\n")
+            "id: dummy\nplugin: shell\ncommand: true\nestimated_duration: 10\n")
         self.assert_common_sdist(tarball)
 
     def test_sdist__partial(self):
@@ -287,7 +290,7 @@ class ProviderManagerToolTests(TestCase):
         """
         with TestIO() as test_io:
             self.tool.main(["validate"])
-        self.assertEqual(test_io.stdout, "All jobs seem to be valid\n")
+        self.assertEqual(test_io.stdout, "The provider seems to be valid\n")
 
     def test_validate__broken_missing_field(self):
         """
@@ -370,8 +373,8 @@ class ProviderManagerToolTests(TestCase):
             "\tdescription: description\n"
             "\tversion: 1.0\n"
             "\tgettext domain: domain\n"
-            "[Job Definitions]\n"
-            "\t'dummy', from jobs/jobs.txt:1-3\n"
+            "[Unit Definitions]\n"
+            "\tjob 2014.com.example::dummy, from jobs/jobs.txt:1-4\n"
             "[White Lists]\n"
             "\t'test', from whitelists/test.whitelist:1-1\n"
             "[Executables]\n"
@@ -389,6 +392,7 @@ class ProviderManagerToolTests(TestCase):
             print("id: dummy", file=stream)
             print("plugin: shell", file=stream)
             print("command: true", file=stream)
+            print("estimated_duration: 10", file=stream)
         os.mkdir(os.path.join(tmpdir, "whitelists"))
         filename = os.path.join(tmpdir, "whitelists", "test.whitelist")
         with open(filename, "wt", encoding='UTF-8') as stream:
